==> zego_uikit_prebuilt_live_streaming-3.0.0.tar.gz: lib/src/events.defines.dart <==
// Flutter imports:
import 'package:flutter/cupertino.dart';

/// The default behavior is to return to the previous page.
///
/// If you override this callback, you must perform the page navigation
/// yourself to return to the previous page!!!
/// otherwise the user will remain on the current call page !!!!!
enum ZegoLiveStreamingEndReason {
  /// the call ended due to a local hang-up
  hostEnd,

  /// the call ended when the remote user hung up, leaving only one local user in the call
  localLeave,

  /// the call ended due to being kicked out
  kickOut,
}

class ZegoLiveStreamingLeaveConfirmationEvent {
  BuildContext context;

  ZegoLiveStreamingLeaveConfirmationEvent({
    required this.context,
  });
}

class ZegoLiveStreamingEndEvent {
  /// the user ID of who kick you out
  String? kickerUserID;

  /// end reason
  ZegoLiveStreamingEndReason reason;

  /// The [isFromMinimizing] it means that the user left the live streaming
  /// while it was in a minimized state.
  ///
  /// You **can not** return to the previous page while it was **in a minimized state**!!!
  /// just hide the minimize page by [ZegoUIKitPrebuiltLiveStreamingController().minimize.hide()]
  ///
  /// On the other hand, if the value of the parameter is false, it means
  /// that the user left the live streaming while it was not minimized.
  bool isFromMinimizing;

  ZegoLiveStreamingEndEvent({
    required this.reason,
    required this.isFromMinimizing,
    this.kickerUserID,
  });

  @override
  String toString() {
    return 'ZegoUIKitLiveStreamingEndEvent{'
        'kickerUserID:$kickerUserID, '
        'isFromMinimizing:$isFromMinimizing, '
        'reason:$reason, '
        '}';
  }
}

==> zego_uikit_prebuilt_live_streaming-3.1.7.tar.gz: lib/src/events.defines.dart <==
// Flutter imports:
import 'package:flutter/cupertino.dart';

/// The default behavior is to return to the previous page.
///
/// If you override this callback, you must perform the page navigation
/// yourself to return to the previous page!!!
/// otherwise the user will remain on the current call page !!!!!
enum ZegoLiveStreamingEndReason {
  /// the live streaming ended due to host ended
  hostEnd,

  /// local user leave
  localLeave,

  /// being kicked out
  kickOut,
}

class ZegoLiveStreamingLeaveConfirmationEvent {
  BuildContext context;

  ZegoLiveStreamingLeaveConfirmationEvent({
    required this.context,
  });
}

class ZegoLiveStreamingEndEvent {
  /// the user ID of who kick you out
  String? kickerUserID;

  /// end reason
  ZegoLiveStreamingEndReason reason;

  /// The [isFromMinimizing] it means that the user left the live streaming
  /// while it was in a minimized state.
  ///
  /// You **can not** return to the previous page while it was **in a minimized state**!!!
  /// just hide the minimize page by [ZegoUIKitPrebuiltLiveStreamingController().minimize.hide()]
  ///
  /// On the other hand, if the value of the parameter is false, it means
  /// that the user left the live streaming while it was not minimized.
  bool isFromMinimizing;

  ZegoLiveStreamingEndEvent({
    required this.reason,
    required this.isFromMinimizing,
    this.kickerUserID,
  });

  @override
  String toString() {
    return 'ZegoLiveStreamingEndEvent{'
        'kickerUserID:$kickerUserID, '
        'isFromMinimizing:$isFromMinimizing, '
        'reason:$reason, '
        '}';
  }
}
